On 9/27/26 8:07 PM, Anton Blanchard wrote:
Set reasonable values for the INT/FP/VEC reassociation widths. I was
able to measure a significant speedup on a dependent FP chain (almost
2x faster) with this applied. I wasn't able to measure a clear
improvement on integer and vector, but I chose conservative values
for both.

gcc/ChangeLog:

        * config/riscv/riscv.cc (tt_ascalon_d8_tune_info): Set
        int_reassoc_width, fp_reassoc_width, and vec_reassoc_width.
Ultimately I think this for you and Peter to reach consensus on. Y'all know this design far better than anyone else where, second guessing would be a bit silly.  So OK pending ack from Peter. Similarly for the loop unrolling patch.

If Peter is delegating to you, then I'd suggest you get commit privs so you can push this kind of stuff for your design forward.

http://gcc.gnu/org/gitwrite.html should have a pointer to the magic form to fill out.  List Peter or I as approving.

jeff

Reply via email to